#
# spec file for package adminer
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2015 Jimmy Berry <jimmy@boombatower.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# pending package submissions to Factory
%bcond_with elasticsearch
%bcond_with mongodb
%bcond_with mssql
Name:           adminer
Version:        4.8.1
Release:        1.11
Summary:        Database management in a single PHP file
License:        GPL-2.0-only OR Apache-2.0
Group:          Productivity/Networking/Web/Frontends

URL:            https://www.adminer.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-httpd.conf
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  php-cli
BuildRequires:  php-tokenizer
BuildRequires:  xz
Requires:       adminer-database-support = %{version}
Requires:       mod_php_any
Requires:       php-iconv
Requires:       php-mbstring
Requires:       php-session
Requires:       php-zlib
Suggests:       adminer-mysql

%description
Adminer (formerly phpMinAdmin) is a full-featured database management tool
written in PHP. Conversely to phpMyAdmin, it consists of a single file ready to
deploy to the target server. Adminer is available for MySQL, PostgreSQL, SQLite,
MS SQL, Oracle, Firebird, SimpleDB, Elasticsearch and MongoDB.


%package editor
Summary:        Data manipulation for end-users
Group:          Productivity/Networking/Web/Frontends
Requires:       adminer = %{version}

%description editor
Adminer Editor is both easy-to-use and user-friendly database data editing tool
written in PHP. It is suitable for common users, as it provides high-level data
manipulation.


%package designs
Summary:        Alternative designs
Group:          Productivity/Networking/Web/Frontends
Requires:       adminer = %{version}

%description designs
Alternative designs for Adminer. Update the symbolic link at
%{apache_datadir}/%{name}/adminer.css to target the desired theme found in
%{apache_datadir}/%{name}/designs/*/adminer.css.

# Define adminer-database-support packages
%package elasticsearch
Summary:        Dependencies required for Adminer ElasticSearch support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pear-horde_elasticsearch

%description elasticsearch
Virtual package that requires dependencies needed for Adminer ElasticSearch support


%package mongodb
Summary:        Dependencies required for Adminer MongoDB support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pear-horde_mongo

%description mongodb
Virtual package that requires dependencies needed for Adminer MongoDB support


%package mssql
Summary:        Dependencies required for Adminer MS SQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-mssql

%description mssql
Virtual package that requires dependencies needed for Adminer MS SQL support


%package mysql
Summary:        Dependencies required for Adminer MySQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-mysql

%description mysql
Virtual package that requires dependencies needed for Adminer MySQL support


%package pgsql
Summary:        Dependencies required for Adminer PostgreSQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pgsql

%description pgsql
Virtual package that requires dependencies needed for Adminer PostgreSQL support


%package sqlite
Summary:        Dependencies required for Adminer SQLite support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-sqlite

%description sqlite
Virtual package that requires dependencies needed for Adminer SQLite support


%prep
%setup -q

%build
# Creates: ./adminer-{version}.php.
./compile.php

# Creates: ./editor-{version}.php.
./compile.php editor

%install
# Remove version from file names.
mv adminer-%{version}.php adminer.php
mv editor-%{version}.php editor.php

# Install files in datadir.
install -d -m 0755 %{buildroot}%{apache_datadir}/%{name}
cp -R adminer.php editor.php designs/ \
  %{buildroot}%{apache_datadir}/%{name}

# Default to hever theme.
ln -s %{apache_datadir}/%{name}/designs/hever/adminer.css \
  %{buildroot}%{apache_datadir}/%{name}

install -D -m 0644 %{SOURCE1} %{buildroot}%{apache_sysconfdir}/conf.d/%{name}.conf
# Fix paths in httpd config.
sed -i -e "s,@apache_datadir@,%{apache_datadir},g" -e "s,@name@,%{name},g" \
  %{buildroot}%{apache_sysconfdir}/conf.d/%{name}.conf

# README for adminer-database-support packages
echo "Virtual package for Adminer database support" > README

%post
# Enable required apache modules.
if [ -x /usr/sbin/a2enmod ] ; then
  # Get installed php_version (5 or 7).
  php_version=$(php -v | grep '(cli)' | awk '{print $2}' | awk -F'.' '{print $1}')
  if [ -n "$php_version" ]; then
    a2enmod -q php${php_version} || a2enmod php${php_version}
    a2enmod -q version || a2enmod version
  fi
fi

%if 0%{?suse_version} < 1310
%restart_on_update apache2
#%%else
#systemctl try-restart apache2 >/dev/null
%endif

%postun
%if 0%{?suse_version} < 1310
%restart_on_update apache2
#%%else
#systemctl try-restart apache2 >/dev/null
%endif

%files
%defattr(-,root,root)
%doc changes.txt
%dir %{apache_datadir}/%{name}
%{apache_datadir}/%{name}/adminer.php
%{apache_datadir}/%{name}/designs/hever/
%config(noreplace) %{apache_datadir}/%{name}/adminer.css
%config(noreplace) %{apache_sysconfdir}/conf.d/%{name}.conf

%files editor
%defattr(-,root,root)
%{apache_datadir}/%{name}/editor.php

%files designs
%defattr(-,root,root)
%{apache_datadir}/%{name}/designs/
%exclude %{apache_datadir}/%{name}/designs/hever/

# Define adminer-database-support packages
%if %{with elasticsearch}
%files elasticsearch
%defattr(-,root,root)
%doc README
%endif

%if %{with mongodb}
%files mongodb
%defattr(-,root,root)
%doc README
%endif

%if %{with mssql}
%files mssql
%defattr(-,root,root)
%doc README
%endif

%files mysql
%defattr(-,root,root)
%doc README

%files pgsql
%defattr(-,root,root)
%doc README

%files sqlite
%defattr(-,root,root)
%doc README

%changelog
* Thu May 20 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.8.1
  * Fix XSS in doc_link
  * MySQL: Allow moving views to other DB and renaming DB with views
  * MariaDB: Do not treat sequences as views
  * PostgreSQL: Support UPDATE OF triggers
  * PostgreSQL: Support triggers with more events (OR)
  * PostgreSQL: Fix parsing of foreign keys with non-ASCII column names
  * PostgreSQL < 10 PDO: Avoid displaying GENERATED ALWAYS BY IDENTITY everywhere
  * SQLite: Fix displayed types
  * Avoid PHP warnings with PDO drivers
  * Fix PHP 8 warnings
* Thu Feb 11 2021 jimmy@boombatower.com
- Update to version 4.8.0:
  * Release 4.8.0
  * Remove .inc extension from driver plugins
  * Oracle: Use correct DB in db_size, fix typo (thanks to Shirai Takashi)
  * MongoDB: Alpha
  * MongoDB: Prefer driver used in other functions
  * Save bytes
  * MongoDB: Fix edit operations in select
  * Fix typo
  * MongoDB: Use ObjectID only if used
  * MongoDB: Fix operators
  * MongoDB: Handle errors
  * MongoDB: Fix query
  * Save bytes
  * MongoDB: Display error when selecting wrong table
  * MongoDB: Display arrays as JSON
  * MongoDB: Fix executeQuery
  * MongoDB: Modern extension doesn't allow connecting with random user/password
  * MongoDB: Add operators
  * MongoDB: Handle exceptions
  * MongoDB: Fix getting binary fields
  * MongoDB: Fix num_rows
  * MongoDB: Move common code to function
  * MongoDB: Display Authentication failed instead of exception
  * Delete duplicate code
  * Fix operators init
  * PostgreSQL: Fix displaying NULL bytea fields
  * Avoid errors about 'view_trigger'
  * Support unprivileged users for schema list
  * Support altering indexes
  * Avoid errors when alter table column
  * Avoid errors about auto increment
  * Support granted table to list up indexes
  * Correct column size with string type
  * Sort the DB list
  * Support importing table data
  * The table with another scheme is deleted from the table list
  * Support computing DB infos
  * PostgreSQL: Do not show triggers from other schemas
  * SimpleDB, Firebird, ClickHouse: Move to plugin
  * Add comments
  * Prepare for moving drivers to plugins
  * Support function default values in insert (bug #713)
  * Allow SQL pseudo-function in insert
  * Save bytes
  * PostgreSQL: Fix multi-parameter functions in default values (bug #736)
  * Add id to <th> in select (bug #724)
  * Remove newline before error message
  * Fix whitespace
  * Add bug number
  * PostgreSQL: Avoid exporting empty sequence last value
  * PostgreSQL: Create PRIMARY KEY for auto increment columns
  * PostgreSQL PDO: Do not select NULL function for false values in edit (thanks to PR #380)
  * MySQL 8: Fix EXPLAIN in SQL command
  * Update tests
  * Add callback before edit form (bug #759)
  * Skip date columns for non-date values in search anywhere (thanks to PR #408)
  * Fix PHP 8 warning
  * Add DB version to comment in export
* Mon Feb  8 2021 jimmy@boombatower.com
- Update to version 4.7.9:
  * Release 4.7.9
  * Reorder changes
  * Editor: Avoid trailing dot in export filename
  * Skip impossible condition ($link always contains ?username=)
  * Fix displayed foreign key columns from other DB (bug #766)
  * Do not display empty database in the list twice
  * Display CSRF logout error after connecting
  * Fix displaying type mapping for Elasticsearch >= 6.0
  * MongoDB: Prefer modern extension
  * Fix MongoDB connect 'Database does not support password.' tips
  * Update bug numbers
  * Postgres - fix missing partitioned tables in navigation
  * Linkify URLs in SQL results
  * Title for select data link
  * Quote values with leading and trailing zeroes in CSV export (bug #777)
  * MySQL: Don't quote default value of text fields (bug #779)
  * fixed Unsupported operand types when $port is socket
  * Respect SQL command URL parameters
  * Fix XSS in browsers which don't encode URL parameters (bug #775)
  * SQLite: Set busy_timeout to 500
  * PostgreSQL 11: Create PRIMARY KEY for auto increment columns
  * PostgreSQL: Support smallserial
  * Add comment
  * PostgreSQL PDO: Support PgBouncer, unsupport PostgreSQL < 9.1 (bug #771)
  * fix wrong hungarian translation
  * Editor: Cast to string when searching (bug #325)
  * Don't syntax highlight during IME composition (bug #747)
  * PostgreSQL: Use bigserial for bigint auto increment (bug #765, regression from 3.0.0)
  * MSSQL: Don't trucate displayed comments to 30 chars (use varchar maximum of 8000 upon casting)
  * Update Korean translation (thanks to B. Cansmile Cha)
  * add alternative design dracula theme
  * show correct collation for PostgresSQL
  * PostgreSQL: Fix current schema in view definition
  * Add external designs as submodules
  * Fixes to lucas-sandery theme
  * Do not export names in quotes with sql_mode='ANSI_QUOTES' (bug #749)
  * Fix PgSQL generated always as identity fix
  * Update Russian translation.
  * Update Ukrainian translation.
  * PostgreSQL: Export all FKs after all CREATE TABLE
  * MySQL, MariaDB: Fix doc links
  * Do not display SQL function for checkbox
  * Fix style (bug #743)
  * PostgreSQL: Fix dollar-quoted syntax highlighting (bug #738)
  * Elasticsearch, ClickHouse: Do not print response if HTTP code is not 200
  * Add basic Makefile.
  * Travis: add php 7.4 && 8.0
  * Re-enable PHP warnings
* Thu Jan 28 2021 Jimmy Berry <jimmy@boombatower.com>
- Drop virtual firebird package since php-firebird was dropped.
  See sr#863764 for Factory decline.
* Sat Jan 16 2021 Arjen de Korte <suse+build@de-korte.org>
- BuildRequires php-cli
* Tue Jan  5 2021 elimat@opensuse.org
- Update to version 4.7.8:
  * Release 4.7.8
  * MySQL: Use renamed variable
  * Avoid PDO exceptions in PHP 8
  * Fix method call after #406
  * Improve check for numeric ports (bug #769)
  * Add missing method
  * Fix compatibility with PHP 8
  * Avoid each() not available in PHP 8
  * Fix style
  * Escape : also in remove_from_param
* Mon May 11 2020 jimmy@boombatower.com
- Update to version 4.7.7:
  * Release 4.7.7
  * Fix open redirect if Adminer is accessible at //adminer.php%%2F@ (thanks to Prakash Sharma)
  * Update Finnish translation
  * Fix typo in Greek translation
  * Add missing translation
  * Fix forwarded IP comparison in login-ip plugin
  * Release 4.7.6
* Fri Jan 31 2020 jimmy@boombatower.com
- Update to version 4.7.6:
  * Release 4.7.6
  * Fix comparing IPs
  * Update readme
  * Add example for using SQLite with Editor
  * PostgreSQL: Support exporting views
  * Disallow connecting to ports > 65535 (bug #730)
  * Display time of procedure execution
  * Hide columns when rendering
  * Speed up alter table form
  * Fix clicking on non-input fields in alter table
  * Editor: Fix focusing foreign key search in select
  * MySQL: Always set foreign_key_checks in export
* Wed Nov 27 2019 jimmy@boombatower.com
- Update to version 4.7.5:
  * Release 4.7.5
  * Re-apply https://github.com/vrana/adminer/pull/363/commits/89b6e9bb
  * Update zh-tw.inc.php
  * Update zh.inc.php
  * Stop using adsrc column
  * fixed: SQL command for insert, create table, etc. new: create/rename table, add/drop/change type for column
  * Fix brazilian portuguese translation
  * Swedish translation
  * Update hever design
  * Don't overwrite variable
  * Add id="" to cells with failed inline edit (bug #708)
  * Unify dumpTable declarations (bug #707)
  * PostgreSQL, Oracle: Set schema for EXPLAIN queries in SQL command (bug #706)
  * Initialize version-noverify sooner (bug #705)
  * Make context in qsa() optional
  * Delete extra newlines
  * correct complement of responsive media query
  * update lucas-sandery theme
  * Add funding
* Tue Oct 22 2019 jimmy@boombatower.com
- Update to version 4.7.4:
  * Release 4.7.4
  * Fix XSS if Adminer is accessible at URL /data:
  * Do not put unused doc links to single driver compiled version
  * Fix PostgreSQL doc root
  * Save bytes
  * add links to oracle docs
  * add links to postgres docs
  * Bump version
* Thu Aug 29 2019 jimmy@boombatower.com
- Update to version 4.7.3:
  * Release 4.7.3
  * Fix blocking of concurrent instances in PHP >7.2 (bug #703)
  * setup Mongo authSource by ENV
  * Reset table after changing DB
  * Move <p> after a possible error
  * Allow editing foreign keys pointing to tables in other database/schema (bug #694)
  * MS SQL: Support foreign keys to other DB
  * Do not display error for foreign keys to other databases
  * Save bytes
  * MSSQL: use textarea in edit form for Memo type (#357)
  * MySQL: Support STORED GENERATED
  * SQLite: Skip renaming when recreating table if not necessary
  * SQLite: Preserve auto increment when recreating table
  * SQLite: Allow setting auto increment for empty tables
  * Remove extra space in alter table command
  * SQLite: Handle error in altering table (bug #697)
  * init mancave-hever design
  * MySQL: Allow editing rows identified by negative floats (bug #695)
  * added floating footer css for adminer-theme-mancave2-2.1.alpha
  * Add a comment (bug #691)
  * Use is_numeric()
  * Support MariaDB virtual columns
  * MySQL: Speed up displaying tables in large databases (bug #700)
  * Support unquoted floats in export
  * SQLite: Quote strings stored in integer columns in export (bug #696)
  * MySQL: Skip editing generated columns
  * Add AdminerLoginIp
  * Close </ul> of logins
* Thu Jul 18 2019 jimmy@boombatower.com
- Update to version 4.7.2:
  * Release 4.7.2
  * MySQL: Fix getting foreign keys
  * Fix table status in PostgreSQL 12 (bug #683)
  * Fix displaying SQL command after Save and continue edit
  * PostgreSQL: Display definitions of materialized views (bug #682)
  * Support for viewing and editing of column comments in mssql driver
  * PostgreSQL: Fix setting column comments on new table
  * MySQL: Fix displaying multi-columns foreign keys (bug #675)
  * Check if PDO SSL Attributes are set within config, and only set them in PDO Options. otherwise Mysql PDO throws errors if attribute is set and empty
  * Elasticsearch: Show executed query as a json
  * MongoDB: number of records should be count on provide rows
  * Keep font size in all tables.
  * travis: test on php 5.6-7.3 (#330)
  * Cache busting for adminer.css
  * Always pass the SRID part of a geometry property with the GeomFromText function
  * Update rmsoft designs
  * Allow bruteForceKey to be overwritten (#342)
  * Allow overwriting tables when copying them
  * Update rmsoft design
  * Stretch footer over the whole table width (bug #624)
  * Do not attempt logging in without password (bug #676)
  * Fix typo in translation (bug #673)
  * missing translation DE
  * Fix too small #lang margin on pepa-linha design
  * Fix creating users and changing password in MySQL 8 (bug #663)
  * Fix #tables margin (#326)
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Replace %%__-type macro indirections.
- Replace bash-specific syntax in scriptlets by POSIX sh.
* Thu Jan 24 2019 jimmy@boombatower.com
- Update to version 4.7.1:
  * Release 4.7.1
  * Remember visible columns in Create Table form (bug #493)
  * Editor: Allow disabling boolean fields in PostgreSQL (bug #640)
  * fix: haeckel adminer.css (#323)
  * SQLite: Hide server field in login form
  * Improve MariaDB status variables link (bug #658)
  * Update zh-tw.inc.php
  * Update zh.inc.php
  * Display the tables scrollbar (bug #647)
  * Document change
  * Fix PHP 7.3 compatibility (#318)
  * Position of the background database image changed. (#316)
  * Fix mvt theme (#315)
  * Use <ul> list for logins (#314)
  * Add missing Japanese translations (thanks to Shirai Takashi)
  * Change '...' to horizontal ellipsis character
  * php <5.4 compat: array syntax (#313)
  * Add autocomplete attributes to login form
* Sun Nov 25 2018 jimmy@boombatower.com
- Update to version 4.7.0:
  * Release 4.7.0
  * Fix whitespace
  * Clarify change description
  * Updated theme for v4.7 (#310)
  * Update zh-tw.inc.php (#299)
  * Fix a typo
  * Delete copy/pasted code
  * Change inline style to class name
  * Wrap `table.nowrap` with `div[style="overflow-x: auto"]`
  * Fix MariaDB link to numeric types
  * MySQL: Descending indexes in MySQL 8 (bug #643)
  * PostgreSQL: Support for GENERATED BY DEFAULT AS IDENTITY
  * Fix style
  * ClickHouse: support for decimal types, SQL operator
  * ClickHouse: Fix for drop multiple tables and views
  * ClickHouse ALTER DELETE and ALTER UPDATE support
  * ClickHouse fix select-like queries format postfix
  * Avoid overwriting existing tables when copying tables (bug #642)
  * PostgreSQL: Export DESC indexes (bug #639)
  * Recognize current_timestamp() in edit (bug #638)
  * Hide import from server if no path
  * Simplify storing executed SQL queries to bookmarks
  * fix editor theme (#302)
  * Remove unused code
  * MySQL: Recognize ON UPDATE current_timestamp() (bug #632)
  * PostgreSQL: Quote array values in export (bug #621)
  * Add plugin pretty-json-column
  * Update translation
  * DOM not ready when restoring `adminer_tables_filter` (#289)
  * Add Georgian translation
  * Update mvt design
  * Fix design (thanks to apmuthu)
  * ClickHouse: Fix escaping
  * ClickHouse support alpha version
  * Fix typo in Vietnamese translation
  * Add class 'layout' to all non-data tables
  * Set default db to sqlsrv connection
  * Warn when using password with leading or trailing spaces
  * Update donation link
  * Make maxlength in all fields a soft limit
  * Increase username maxlength to 80 (bug #623)
  * Fixes foreign key pattern in MySQL
  * Fix function change with set data type (thanks to osoba hrdelnata)
  * Adminer theme
  * Reset event handlers after cloning (thanks to Salko)
  * Fix inline editing of empty cells
* Thu Jun 28 2018 jimmy@boombatower.com
- Update to version 4.6.3:
  * Release 4.6.3
  * Fix typo
  * Revert "PgSQL search operator "SQL" added"
  * Add TODO
  * MySQL: Disallow LOAD DATA LOCAL INFILE
  * PostgreSQL: Export false as 0 in PDO (bug #619)
  * mssql: ignore serverproperty error
  * Add spaces
  * Fix table list in sidebar in designs/pokorny (#278)
  * Allow AdminerTablesFilter plugin to be used with third-party table list plugins (#275)
  * Recommend inlining the hash
  * Improve error message
  * Escape \ in enum edit
  * Improve enum parsing
  * Order database names in MySQL 8(bug #613)
  * Respect 'session.cookie_secure' if it is On
  * Copy triggers when copying table
  * MS SQL: Support port with sqlsrc
  * PostgreSQL: Do not cast uuid searches to text (bug #608)
  * Editor: Do not check boolean checkboxes with false in PostgreSQL (bug #607)
  * Disallow using password-less databases
  * MongoDB: Consolidate code
  * MongoDB: Consolidate code
  * MongoDB: Consolidate code
  * MongoDB: Report version
  * Document that Elasticsearch requires allow_url_fopen
  * PostgreSQL: Do not cast boolean to text on search (#264)
  * PostgreSQL: Do not cast number searches to text
  * PostgreSQL: Fix editing data in views (bug #605)
  * Elasticsearch: Fix PHP warning
  * PgSQL search operator "SQL" added
  * PostgreSQL: Fix slow query
  * Update JUSH
  * Display that *.gz files are supported in file upload
  * Save bytes
  * Stay on import page when switching database
  * Decrease timeout for running slow queries from 5 seconds to 2 seconds
  * Simplify running slow queries
  * Remove unused argument
  * Update JUSH
  * Use JUSH from GitHub
  * Clarify changelog
  * Display missing database in navigation
  * MongoDB driver: Add create_database methods.
  * Fix comment
  * Add $driver to global variables
  * Add $driver to global variables
  * Use $adminer->operators
  * PostgreSQL: Do not cast time search
  * Do not cast date/timestamp exact searches in PostgreSQL to text
  * Do not cast date/timestamp exact searches in PostgreSQL to text
  * MySQL: Use CONVERT() only when searching for non-ASCII (bug #603)
  * Remove optional submodule
  * Update adminer-design (rmsoft) to version 4.6.2.1
  * Wrap lines
  * Fix displaying info about non-alphabetical objects (bug #599)
  * Allow connecting to different drivers in login-servers
  * Wrap long line
  * Add login-otp plugin
  * Update translation
  * Comment
  * Centralize stopping session
  * Stop session before connecting (thanks to Kareem Zidane)
  * Update design (thanks to Jan)
  * PDO: Support binary fields download
  * Don't try to check missing checkboxes
  * Use file caching only in non-dev
  * Editor: Delete images from compiled version
  * Remove driver from file URLs (stored in path)
  * Fix image in compiled version
  * Use single \ in ' strings
  * &nbsp; is not needed with border-collapse
* Tue Feb 20 2018 jimmy@boombatower.com
- Update to version 4.6.2:
  * Release 4.6.2
  * Fix test
  * Fix typo
  * Comment
  * Use function after declaring it
  * Remove test server
  * Make test works with MariaDB
  * Make test work on wide screen
  * Editor: Fix displaying of true boolean values
  * Comment
  * Store current version before authentication and in Editor
  * Update design (thanks to Jan)
  * Add missing fullstop
  * Version 4.6.1.1 (#254)
  * Turkish language file updated.
  * Align Whole result
  * Always hide import
  * Print email only with rows or page
  * Move import out of footer
  * Move pagination to fieldset
  * Update readme
  * Make Login test work with jush-textarea
  * Add SQLite test
  * Test warnings
  * Convert tests to Katalon
  * Promote MongoDB, demote Oracle and MS SQL
  * Capitalize Whole result
  * Fill footer to the right
  * Make footer smaller
  * Move pagination outside footer
  * Wrap more into if (!is_ajax)
  * Move <p>
  * PostgreSQL: Add IF EXISTS to DROP SEQUENCE in export (bug #595)
  * Make footer border more obvious
  * Make footer margin not transparent
  * Centralize oninput
  * Speed up alter table
  * Use Unicode arrows in alt
  * Avoid hiding column only to show it later
  * Respect unchecked Default values
  * Update UI when coming from history
  * PostgreSQL: Fix exporting string default values (thanks to PotatoPangolin)
  * Semi-transparent border on table actions
  * Fix exporting sequences in PostgreSQL 10
  * Do not append empty values
  * Shorten JSON values in select (bug #594)
  * Fix id in databases list
  * Suggest updating Git submodules
  * Declare MariaDB support
* Fri Feb  9 2018 jimmy@boombatower.com
- Update to version 4.6.1:
  * Release 4.6.1
  * Round 9.2 to 9.2
  * MariaDB: Links to documentation in syntax highlighting
  * Display notification about performing action after relogin
  * Reorder changes
  * Allow specifying server name displayed in breadcrumbs
  * MariaDB: Links to documentation
  * Reorder changes
  * Remove .lcZ from timeFormat (bug #593)
  * Add todo
  * Add more system tables help links
  * Respect empty tableName in tablesPrint
  * Use tableName() in table.inc.php
  * Avoid qsl in a loop
  * Support Shift+click in server export
  * Avoid qsl in a loop
  * Sticky position of table actions
  * Document regression
  * Avoid qsl in check[]
  * Avoid qsl in a loop
  * Mark optional parameter
  * SQLite: Support ` in PRIMARY KEY
  * Avoid Invalid credentials with no credentials
  * SQLite: Allow deleting PRIMARY KEY from tables with auto increment
  * Do not wrap alter table thead
  * Add version() to use in plugins
  * Select original if nothing else is selected
  * Remove nested array
  * Support connecting to MySQL via SSL
  * Display Invalid credentials if connection error is empty
  * Delete unused functions
  * Ignore functions in Min_Driver
  * Remove unnecessary quotes
  * Add truncate_sql to PostgreSQL
  * PostgreSQL: Unescape bytea fields
  * Save bytes
  * Add missing function to compile.php
  * PostgreSQL: Upload binary files to bytea fields
  * Allow using number_type() as pattern
  * Translate thousands separator in JS
  * Editor: Use type=search for Search tables
  * Move tableCheck() below </form>
  * Pass operator from db.inc.php
  * PostgreSQL: Cast to string when searching using LIKE (bug #325)
  * MySQL: Support non-utf8 charset in search in column
  * Use ST_GeomFromText in MySQL 8 (bug #574)
  * Do not modify $_GET["where"]
  * Display empty operator as LIKE %%%%
  * Fix whitespace
  * Avoid deprecated each()
  * PostgreSQL: Fix condition for selecting no rows
  * Fix error display in Search tables
  * PostgreSQL: Don't treat interval type as number (bug #474)
  * Pass required parameter
  * Use existing variable
  * Add class to use in designs
  * Use primary key instead of LIMIT 1 if available
* Mon Feb  5 2018 jimmy@boombatower.com
- Update to version 4.6.0:
  * Release 4.6.0
  * Fix affected rows after getting warnings
  * Fix number of affected rows after getting warnings
  * Fix test
  * Fix 5.1 being displayed as 5.09999...
  * PRIMARY KEY in SQLite
  * Add design Esterka
  * Disable autocompleting password on create user page
  * Use primary key to edit rows even if not selected
  * Space between DB and Use
  * Translate DB
  * Select converted fields only once
  * Don't count rows if we reached the end
  * Fix count_rows with more than one group by column
  * Use separator in limit1
  * SQLite: Limit rows in data manipulation without unique key
  * Document that tests don't work with oninput
  * PostgreSQL: Limit rows in data manipulation without unique key
  * Don't use ctid as it's not stable
  * Move variables close to their usage
  * Limit non-unique where updates
  * Use Oid as the name of the column
  * Save bytes
  * Update rmsoft design
  * MySQL: Add FIND_IN_SET search operator
  * Add rmsoft design
  * MySQL: Add floor and ceil functions
  * Fix links to PostgreSQL 10 documentation
  * Delete unused variable
  * Display options for timestamp columns when creating a new table (thanks to Robert Vlach)
  * Don't display warnings for failed queries
  * Fix variable name
  * Reorder variables
  * Use pg_last_notice only with pgsql
  * Print warnings in call
  * Pass start time to selectQuery
  * PostgreSQL: Display warnings
  * Return string from warnings()
  * Display warnings in messages
  * Show select warnings
  * Support X-Forwarded-Prefix (e.g. Traefik PathPrefixStrip feature)
  * Lowercase EXPLAIN but don't translate it
  * Move explain below warnings
  * Fix return type
  * MySQL: Display warnings in SQL command
  * Quote default values not starting with a letter
  * Stop redirecting links via adminer.org
  * Fix min_version use
  * Quote dates in default value
  * Fully support functions in default values
  * Fix min_version use
  * PostgreSQL: Allow now() as default value (bug #525)
  * Fix edit_type after 1f21cd43
  * PostgreSQL: Allow editing views with uppercase letters (bug #467)
  * PostgreSQL: Allow creating trigger functions
  * Add placeholders
  * PostgreSQL: Support functions
  * Add min_version to compile.php
  * SimpleDB: Document that allow_url_fopen is required (bug #340)
  * Focus correct field in selectSearch
  * Support JSON since MariaDB 10.2 (bug #590)
  * Use min_version
  * Add min_version
  * Save bytes
  * add malay translation
  * Added and translated missing keys in polish translation
  * Update compatibility with TinyMCE v4 (#247)
  * Fix elastic after ef5a7639
  * fix elastic.inc.php to work on PHP 5.2
  * Fix counting selected rows after going back to select page
* Thu Jan 25 2018 jimmy@boombatower.com
- Update to version 4.5.0:
  * Release 4.5.0
  * Fix tests after 95d02bb9
  * Simplify drop object confirmation questions
  * Translate message added in 4.4.0
  * Display name of the object in confirmation when dropping it
  * Display error when getting row to edit
  * Avoid CONVERT() except in MySQL (bug #509)
  * Bump version
  * MySQL: Support routines with comments in parameters (bug #460)
  * Verify if adminer.version was created on www.adminer.org
  * Store current Adminer version server-side to avoid excessive requests
  * Send token as last param
  * Allow using adminer.invalid by other users in a group
  * Extract file_open_lock and file_write_unlock
  * Display boolean values as code (bug #562)
  * MariaDB: Support fulltext and spatial indexes in InnoDB (bug #583)
  * PostgreSQL: Display foreign tables (bug #576)
  * Add designs.php
  * Fix compiled version after 5cc831c1
  * Hide window.opener from pages opened in a new window (bug #561)
  * Fix GPL version
  * Add plugin for switching designs
  * Display bold parts of error (bug #565)
  * Add bottom border to last cells
  * Editor: Fix displaying of false values in PostgreSQL (bug #568)
  * Decrease float precision (bug #578)
  * Add ability to override file name (path) when loading dump from webserver
  * Support current_timestamp() as default of time fields (bug #572)
  * Display newlines in column comments (bug #573)
  * MySQL: Support geometry in MySQL 8 (bug #574)
  * MSSQL driver fixed for freetds drivers. See bug #167, #291
  * Fix search focus (regression from 4.4.0)
  * Compatibility with PHP < 5.3
  * Add mongodb as a possible driver
  * Save bytes
  * php7 support with minimal changes of original code
  * PostgreSQL: Export DROP SEQUENCE if dropping table
  * PostgreSQL: Do not export triggers if not requested
  * Ignore removed CREATE+ALTER mode in trigger_sql()
  * Fix whitespace
  * CSP: Allow any CSS
  * adminer-theme-mancave2-2.0.alpha
  * Fix NULL value in edit form with Postgres
  * Do not warn about MySQL specific functions
  * Fix single driver non-MySQL compiled versions (regression from 150301ed)
  * Hide driver selection in single-driver version (regression from e762a6aa)
  * Unify HTML for list of tables in Editor according to Adminer
  * Encapsulate fulltext part in search box into <div>
  * Enhance ElasticSearch integration
  * Allow PHP 5.6 in Travis
  * Select numeric database name in DB list (bug #580)
  * SQLite: Enable foreign key checks
  * CSP: Allow any images, media and fonts, disallow base-uri
  * Define JS functions in AdminerTablesFilter sooner
  * Adminer: Fix Search data in tables
* Wed Jan 17 2018 jimmy@boombatower.com
- s/or/OR/ in License.
- Update to version 4.4.0:
  * Release 4.4.0
  * Allow sending multiple CSP headers
  * Use __construct for constructor
  * Set session cache limiter only without session.auto_start (bug #586)
  * Add missing newline
  * Require specifying credentials in login-sqlite plugin
  * Avoid count(null)
  * Disallow PHP 5.3 in Travis
  * Disallow connecting to privileged ports (thanks to hyp3rlinx)
  * Rate limit password-less login attempts from the same IP address (thanks to hyp3rlinx)
  * Use HTTPS
  * Use HTTPS in doc_link()
  * Do not set '' for empty enum
  * Fix select function onchange
  * Clone all event handlers in cloneNode()
  * Use border-collapse to prevent unnecessary wrapping in Chrome
  * Fix whitespace
  * Fix selectCount() in information_schema
  * Fix SQL command toggle
  * Disallow scripts without nonce
  * Fix wrapping in Create table
  * Use script_src for <script src>
  * Fix typo in script()
  * Do not send empty CSP
  * Move inline event handlers to <script>
  * Move inline event handlers to <script>
  * Use the fact that we handle oninput in whisper()
  * Move inline event handlers to <script>
  * Editor: Fix Search data in tables
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler for skipping original
  * Move inline event handlers to <script>
  * Return false from editingMoveRow()
  * Move inline event handlers to <script>
  * Use oninput instead of onchange
  * Move inline event handlers to <script>
  * Fix fieldChange() after 6353a898
  * Use oninput instead of onkeyup
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler in on_help()
  * Move inline event handlers to <script>
  * Clone onchange in cloneNode()
  * Move inline event handlers to <script>
  * Allow searching data in tables by Ctrl+Enter
  * Move inline event handlers to <script>
  * Fix selectors in schema after 58b2904d
  * Rely on event always passed to handlers
  * Move inline event handlers to <script>
  * Return false from editingRemoveRow
  * Move inline event handlers to <script>
  * Use script() for <script>
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler in print_fieldset()
  * Use <script> instead of inline event handler in confirm()
  * Move inline event handlers to <script>
  * Return false from ajaxSetHtml()
  * Move inline event handlers to <script>
  * Revert using @this in formChecked
  * Move inline event handlers to <script>
  * Return false from toggle()
  * onchange='selectFieldChange
  * Use @this in selectFieldChange
  * Move inline event handlers to <script>
  * Fix indexesAddColumn after 14778165
  * Move inline event handlers to <script>
  * Revert using @this in formChecked
  * Allow customizing CSP
  * Allow img-src data: common in skins
  * Use JSON.parse if available
  * Add Content Security Policy
  * Always send security headers in customization
  * Add nosniff header
  * Use Referrer-Policy instead of <meta name="referrer">
  * Editor: Fix doubleclick on database page
  * Fix a typo from 9cb28186
  * Use @this in JavaScript (prepares for removing inline event handlers)
  * Prevent PHP 7.1 warning about non-numeric values
  * Unindent doc-comments
  * Delete type="text/css" from <style> as it is the default in HTML5
  * Delete type="text/javascript" from <script> as it is the default in HTML5
  * Replace getElementsByTagName by shortcut for querySelectorAll
  * Use querySelector
  * Replace getElementById by shortcut for querySelector (requires IE8)
  * Fix skin for Chrome 61 (thanks to Dominik Ulrich)
  * Editor: Display field comment's text inside [] only in edit form
  * Fix hebrew typos (#228)
  * Add new Hebrew translations
  * Add Hebrew translation
  * Editor: Don't set time zone from PHP
  * Make sure all sidebar elements are pushed down, not just the form.
  * Update AdminerTablesFilter to produce li as per c9801e2e2418
  * MySQL: Remove dedicated view for replication status
  * Sort table names (bug #552)
  * Update es.inc.php
  * Add a donate link
* Sat Oct 28 2017 jimmy@boombatower.com
- Disable elasticsearch and mssql since the dependencies are no
  longer present in Factory.
* Mon Sep 11 2017 jimmy@boombatower.com
- Update a2enmod php5 to check for php version (boo#1058106).
* Fri Apr 14 2017 jimmy@boombatower.com
- Update to version 4.3.1:
  * PostgreSQL: Fix index size computation in PostgreSQL < 9.0 (reverts 4c78976c)
  * Fix PostgreSQL nullable fields in export
  * Fix table dependency on export
  * Updating Russian translation
  * Update haeckel design (thanks to Klemens Haeckel)
  * PostgreSQL: Support JSON and JSONB data types (bug #542)
  * PostgreSQL: Fix JSONB version support
  * Don't overwrite previous cookies (bug #539)
  * Add a todo
  * Fix SQL command autofocus
  * Release 4.3.1
* Wed Mar 15 2017 jimmy@boombatower.com
- Update to version 4.3.0:
  * Update Indonesian translation (thanks to Benny)
  * Add accessibility labels to Create Table fields
  * Make maxlength in edit fields a soft limit
  * Add Cache-Control: immutable to static files
  * Change comment not supported by compile.php
  * Changed 'geraakt' to 'beinvloed' in Dutch translation
  * Disallow selecting driver if there's only one
  * Add SQLite auto-login plugin
  * RTL layout fixes
  * Additional theme with responsive and RTL support
  * Escape quote in field name to make it work in Chrome (thanks to zcepenela pani)
  * Add accessibility labels to databases and tables checkboxes
  * Use class instead inline style
  * Add accessibility labels to Indexes
  * Add accessibility labels to Foreign keys
  * mistype correction
  * Fix error found by PHPStan
  * postgresql : unique partial index musn't be considered as unique. can cause problems on row edition
  * postgresql : ERROR: function connection_id() does not exist
  * PHP Warning hidden and better parsing times (at least for postgresql)
  * Plugin which shows sql structure comments in field names title
  * Fixed mssql driver for usage with microsoft's php7 sqlsrv extension
  * Changed 'undefined' to 'null'
  * Use null instead of undefined on after parsing JSON
  * Added pdo_dblib as a driver for MSSQL (as native MSSQL driver does not exist for PHP7)
  * Document changes
  * Fixed background of the list of the tables.
  * postgresql error with index on hidden columns (ctid)
  * Fix index length with Postgresql
  * Tabs must also be escaped in JSON strings
  * Plugin: Use <select> on custom user types in psql
  * Added support for binary foreign keys selection on edit
  * Update AdminerTablesFilter
  * AdminerTablesFilter: Persist filter value in a tab
  * Improve limit check in edit-foreign plugin
  * fixed Elastic table_status()
  * Handle checkboxes properly in selectAddRow()
  * Move rendering of table structure and indexes list into plugin system
  * Add plugin for printing table structure in expanded format
  * Add plugin for printing table indexes structure in expanded format
  * PostgreSQL export: table structure, columns, sequences, indexes, foreign keys, comments, trigger definition
  * make bytea fields shortable
  * New skin 'flat'
  * Do not set input type as numeric if field is an array
  * Add namespace to routine call
  * Edit json and jsonb types in textarea
  * Breadcumb no longer blocks the logout button.
  * Hide databases the user can't connect to
  * fix logger for SQL commands
  * Fix MS SQL Driver to not show warnings for version fetching on connection and to retrieve the next set of results properly
  * Changed NULL format
  * Tables list implemented as <ul>
  * foreign key link fix - added missing ns
  * Add javascript move for editing
  * Verify commit success after import.
  * PostgreSQL: Fix index size computation
  * PostgreSQL: Allow changing materialized views
  * Fixed all alternative designs after changes in a list of tables made here: https://github.com/vrana/adminer/pull/116
  * Checkbox for bool in psql
  * Add basic support for MySQL replication
  * Add Czech translation
  * Display message about missing master status
  * Add jsonly class to JS checkboxes
  * Fix where() escaping in MS SQL (bug #496)
  * Support high Unicode characters in shorten_utf8 (bug #481)
  * Use 'Create database' instead of 'Create new database'
  * Move 'Create user' above the list of users
  * Fix dropping foreign keys linking to other database
  * MySQL: Support spatial indexes (bug #455)
  * Save bytes
  * Elasticsearch: Support HTTPS by inputting https://server (bug #446)
  * Unindent
  * Hide materialized views in MySQL
  * Elasticsearch: allow empty server name
  * Bump version
  * Avoid referencing global variable (doesn't work in PHP 7.1 if Adminer is included inside a function)
  * Document new engines
  * Simplify SQLite development
  * Lint PHP files
  * Save bytes
  * Update URL
  * Improve SQLite login error message
  * Rely on noreferrer in Firefox too
  * Use SameSite cookies (except session cookie)
  * Support MySQL 8
  * MySQL: Support JSON data type
  * Print number of bytes in blob in italics
  * Highlight JSON
  * Update JUSH
  * Reorder changelog
  * Release 4.3.0
- Utilize version rewrite to drop v from tag.
* Sun Jan 22 2017 chris@computersalat.de
- fix adminer-http.conf file
  * absence of 'mod_version' is no guarantee to be on apache < 2.4
* Wed Jun  1 2016 jimmy@boombatower.com
- Update to version v4.2.5:
  + Fix http:// links in stylesheets to protocol-independent ones (//)
  + improved kill command support for MySQL and initial support for PgSQL
  + Remove global variable
  + Fix remote execution in SQLite query (thanks to Vincent Waart)
  + SQLite: Require credentials to use (thanks to Vincent Waart)
  + Release 4.2.5
* Tue Feb  9 2016 jimmy@boombatower.com
- Update to 4.2.4.
  + Add escaping (not fixing any XSS)
  + Release 4.2.3
  + Use HTTPS Google Font URL
  + Support PHP 7
  + Delete unused variable and method
  + Bosnian language
  + Add Bosnian translation
  + Add Finnish translation
  + Fix remote execution in SQLite query (discovered by 庞申杰(千霄))
  + Release 4.2.4
* Wed Dec  9 2015 jimmy@boombatower.com
- Correct elasticsearch and mongodb virtual package requires.
- Add %%bcond_with mongodb until submitted to Factory.
* Tue Nov 24 2015 jimmy@boombatower.com
- Correct license to 'GPL-2.0 or Apache-2.0'.
* Mon Nov 16 2015 jimmy@boombatower.com
- Update to 4.2.3.
* Fri Nov 13 2015 aj@ajaissle.de
- Spec file reworked, adjusted apache2 conf.
* Sat Aug  8 2015 jimmy@boombatower.com
- Update to 4.2.2.
* Wed Jul  1 2015 jimmy@boombatower.com
- Initial import of 4.2.1.
